# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs
from ._inputs import *

__all__ = ['VpcAttachmentArgs', 'VpcAttachment']

@pulumi.input_type
class VpcAttachmentArgs:
    def __init__(__self__, *,
                 attach_points: pulumi.Input[Sequence[pulumi.Input['VpcAttachmentAttachPointArgs']]],
                 transit_router_id: pulumi.Input[builtins.str],
                 vpc_id: pulumi.Input[builtins.str],
                 appliance_mode_enabled: Optional[pulumi.Input[builtins.bool]] = None,
                 auto_publish_route_enabled: Optional[pulumi.Input[builtins.bool]] = None,
                 description: Optional[pulumi.Input[builtins.str]] = None,
                 ipv6_enabled: Optional[pulumi.Input[builtins.bool]] = None,
                 tags: Optional[pulumi.Input[Sequence[pulumi.Input['VpcAttachmentTagArgs']]]] = None,
                 transit_router_attachment_name: Optional[pulumi.Input[builtins.str]] = None):
        """
        The set of arguments for constructing a VpcAttachment resource.
        :param pulumi.Input[builtins.str] transit_router_id: 中转路由器实例的ID。
        :param pulumi.Input[builtins.str] vpc_id: 私有网络实例的ID。
        :param pulumi.Input[builtins.bool] appliance_mode_enabled: 是否启动路径一致模式。请严格按照以下枚举值的大小写输入，不要传入其他取值。true：是。开启后，TR转发流量至该VPC连接时，将选择相同的可用区连接点转发请求流量和返回流量。false：否。
        :param pulumi.Input[builtins.bool] auto_publish_route_enabled: 是否自动同步TR路由到网络实例路由表中。请严格按照以下枚举值的大小写输入，不要传入其他取值。true：是，表示系统会自动同步该网络实例连接关联转发的TR路由表中的路由条目到网络实例的路由表中，仅当该参数配置为true，且网络实例连接关联转发的TR路由表中存在路由条目时，系统才会自动同步TR路由到网络实例的路由表中。false（默认值）：否。
        :param pulumi.Input[builtins.str] description: 网络实例连接的描述信息。必须以字母、数字或中文开头，可包含字母、数字、中文和以下特殊字符：英文逗号（,）、点号（.）、下划线（_）、空格（ ）、等号（=）、短横线（-）、中文逗号（，）、中文句号（。）。长度限制为0 ~ 255个字符。不传入该参数或该参数不传入数值时，默认为空字符串。
        :param pulumi.Input[builtins.bool] ipv6_enabled: 是否开启IPv6功能。请严格按照以下枚举值的大小写输入，不要传入其他取值。true：是。false：否。
        :param pulumi.Input[builtins.str] transit_router_attachment_name: 网络实例连接的名称。必须以字母、数字或中文开头，可包含字母、数字、中文和以下特殊字符：点号（.）、下划线（_）和短横线（-）。长度限制为1 ~ 128个字符。不传入该参数或该参数不传入数值时，默认为网络实例连接的ID。
        """
        pulumi.set(__self__, "attach_points", attach_points)
        pulumi.set(__self__, "transit_router_id", transit_router_id)
        pulumi.set(__self__, "vpc_id", vpc_id)
        if appliance_mode_enabled is not None:
            pulumi.set(__self__, "appliance_mode_enabled", appliance_mode_enabled)
        if auto_publish_route_enabled is not None:
            pulumi.set(__self__, "auto_publish_route_enabled", auto_publish_route_enabled)
        if description is not None:
            pulumi.set(__self__, "description", description)
        if ipv6_enabled is not None:
            pulumi.set(__self__, "ipv6_enabled", ipv6_enabled)
        if tags is not None:
            pulumi.set(__self__, "tags", tags)
        if transit_router_attachment_name is not None:
            pulumi.set(__self__, "transit_router_attachment_name", transit_router_attachment_name)

    @property
    @pulumi.getter(name="attachPoints")
    def attach_points(self) -> pulumi.Input[Sequence[pulumi.Input['VpcAttachmentAttachPointArgs']]]:
        return pulumi.get(self, "attach_points")

    @attach_points.setter
    def attach_points(self, value: pulumi.Input[Sequence[pulumi.Input['VpcAttachmentAttachPointArgs']]]):
        pulumi.set(self, "attach_points", value)

    @property
    @pulumi.getter(name="transitRouterId")
    def transit_router_id(self) -> pulumi.Input[builtins.str]:
        """
        中转路由器实例的ID。
        """
        return pulumi.get(self, "transit_router_id")

    @transit_router_id.setter
    def transit_router_id(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "transit_router_id", value)

    @property
    @pulumi.getter(name="vpcId")
    def vpc_id(self) -> pulumi.Input[builtins.str]:
        """
        私有网络实例的ID。
        """
        return pulumi.get(self, "vpc_id")

    @vpc_id.setter
    def vpc_id(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "vpc_id", value)

    @property
    @pulumi.getter(name="applianceModeEnabled")
    def appliance_mode_enabled(self) -> Optional[pulumi.Input[builtins.bool]]:
        """
        是否启动路径一致模式。请严格按照以下枚举值的大小写输入，不要传入其他取值。true：是。开启后，TR转发流量至该VPC连接时，将选择相同的可用区连接点转发请求流量和返回流量。false：否。
        """
        return pulumi.get(self, "appliance_mode_enabled")

    @appliance_mode_enabled.setter
    def appliance_mode_enabled(self, value: Optional[pulumi.Input[builtins.bool]]):
        pulumi.set(self, "appliance_mode_enabled", value)

    @property
    @pulumi.getter(name="autoPublishRouteEnabled")
    def auto_publish_route_enabled(self) -> Optional[pulumi.Input[builtins.bool]]:
        """
        是否自动同步TR路由到网络实例路由表中。请严格按照以下枚举值的大小写输入，不要传入其他取值。true：是，表示系统会自动同步该网络实例连接关联转发的TR路由表中的路由条目到网络实例的路由表中，仅当该参数配置为true，且网络实例连接关联转发的TR路由表中存在路由条目时，系统才会自动同步TR路由到网络实例的路由表中。false（默认值）：否。
        """
        return pulumi.get(self, "auto_publish_route_enabled")

    @auto_publish_route_enabled.setter
    def auto_publish_route_enabled(self, value: Optional[pulumi.Input[builtins.bool]]):
        pulumi.set(self, "auto_publish_route_enabled", value)

    @property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        网络实例连接的描述信息。必须以字母、数字或中文开头，可包含字母、数字、中文和以下特殊字符：英文逗号（,）、点号（.）、下划线（_）、空格（ ）、等号（=）、短横线（-）、中文逗号（，）、中文句号（。）。长度限制为0 ~ 255个字符。不传入该参数或该参数不传入数值时，默认为空字符串。
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "description", value)

    @property
    @pulumi.getter(name="ipv6Enabled")
    def ipv6_enabled(self) -> Optional[pulumi.Input[builtins.bool]]:
        """
        是否开启IPv6功能。请严格按照以下枚举值的大小写输入，不要传入其他取值。true：是。false：否。
        """
        return pulumi.get(self, "ipv6_enabled")

    @ipv6_enabled.setter
    def ipv6_enabled(self, value: Optional[pulumi.Input[builtins.bool]]):
        pulumi.set(self, "ipv6_enabled", value)

    @property
    @pulumi.getter
    def tags(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['VpcAttachmentTagArgs']]]]:
        return pulumi.get(self, "tags")

    @tags.setter
    def tags(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['VpcAttachmentTagArgs']]]]):
        pulumi.set(self, "tags", value)

    @property
    @pulumi.getter(name="transitRouterAttachmentName")
    def transit_router_attachment_name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        网络实例连接的名称。必须以字母、数字或中文开头，可包含字母、数字、中文和以下特殊字符：点号（.）、下划线（_）和短横线（-）。长度限制为1 ~ 128个字符。不传入该参数或该参数不传入数值时，默认为网络实例连接的ID。
        """
        return pulumi.get(self, "transit_router_attachment_name")

    @transit_router_attachment_name.setter
    def transit_router_attachment_name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "transit_router_attachment_name", value)


@pulumi.input_type
class _VpcAttachmentState:
    def __init__(__self__, *,
                 appliance_mode_enabled: Optional[pulumi.Input[builtins.bool]] = None,
                 attach_points: Optional[pulumi.Input[Sequence[pulumi.Input['VpcAttachmentAttachPointArgs']]]] = None,
                 auto_publish_route_enabled: Optional[pulumi.Input[builtins.bool]] = None,
                 bandwidth: Optional[pulumi.Input[builtins.int]] = None,
                 created_time: Optional[pulumi.Input[builtins.str]] = None,
                 description: Optional[pulumi.Input[builtins.str]] = None,
                 ipv6_enabled: Optional[pulumi.Input[builtins.bool]] = None,
                 status: Optional[pulumi.Input[builtins.str]] = None,
                 tags: Optional[pulumi.Input[Sequence[pulumi.Input['VpcAttachmentTagArgs']]]] = None,
                 transit_router_attachment_id: Optional[pulumi.Input[builtins.str]] = None,
                 transit_router_attachment_name: Optional[pulumi.Input[builtins.str]] = None,
                 transit_router_id: Optional[pulumi.Input[builtins.str]] = None,
                 updated_time: Optional[pulumi.Input[builtins.str]] = None,
                 vpc_id: Optional[pulumi.Input[builtins.str]] = None):
        """
        Input properties used for looking up and filtering VpcAttachment resources.
        :param pulumi.Input[builtins.bool] appliance_mode_enabled: 是否启动路径一致模式。请严格按照以下枚举值的大小写输入，不要传入其他取值。true：是。开启后，TR转发流量至该VPC连接时，将选择相同的可用区连接点转发请求流量和返回流量。false：否。
        :param pulumi.Input[builtins.bool] auto_publish_route_enabled: 是否自动同步TR路由到网络实例路由表中。请严格按照以下枚举值的大小写输入，不要传入其他取值。true：是，表示系统会自动同步该网络实例连接关联转发的TR路由表中的路由条目到网络实例的路由表中，仅当该参数配置为true，且网络实例连接关联转发的TR路由表中存在路由条目时，系统才会自动同步TR路由到网络实例的路由表中。false（默认值）：否。
        :param pulumi.Input[builtins.int] bandwidth: 网络实例连接的带宽上限，单位为Gbps。
        :param pulumi.Input[builtins.str] created_time: 创建时间。
        :param pulumi.Input[builtins.str] description: 网络实例连接的描述信息。必须以字母、数字或中文开头，可包含字母、数字、中文和以下特殊字符：英文逗号（,）、点号（.）、下划线（_）、空格（ ）、等号（=）、短横线（-）、中文逗号（，）、中文句号（。）。长度限制为0 ~ 255个字符。不传入该参数或该参数不传入数值时，默认为空字符串。
        :param pulumi.Input[builtins.bool] ipv6_enabled: 是否开启IPv6功能。请严格按照以下枚举值的大小写输入，不要传入其他取值。true：是。false：否。
        :param pulumi.Input[builtins.str] status: 网络实例连接的状态。Creating: 创建中。Deleting: 删除中。Pending：配置中。Available：可用。
        :param pulumi.Input[builtins.str] transit_router_attachment_id: 网络实例连接的ID。
        :param pulumi.Input[builtins.str] transit_router_attachment_name: 网络实例连接的名称。必须以字母、数字或中文开头，可包含字母、数字、中文和以下特殊字符：点号（.）、下划线（_）和短横线（-）。长度限制为1 ~ 128个字符。不传入该参数或该参数不传入数值时，默认为网络实例连接的ID。
        :param pulumi.Input[builtins.str] transit_router_id: 中转路由器实例的ID。
        :param pulumi.Input[builtins.str] updated_time: 更新时间。
        :param pulumi.Input[builtins.str] vpc_id: 私有网络实例的ID。
        """
        if appliance_mode_enabled is not None:
            pulumi.set(__self__, "appliance_mode_enabled", appliance_mode_enabled)
        if attach_points is not None:
            pulumi.set(__self__, "attach_points", attach_points)
        if auto_publish_route_enabled is not None:
            pulumi.set(__self__, "auto_publish_route_enabled", auto_publish_route_enabled)
        if bandwidth is not None:
            pulumi.set(__self__, "bandwidth", bandwidth)
        if created_time is not None:
            pulumi.set(__self__, "created_time", created_time)
        if description is not None:
            pulumi.set(__self__, "description", description)
        if ipv6_enabled is not None:
            pulumi.set(__self__, "ipv6_enabled", ipv6_enabled)
        if status is not None:
            pulumi.set(__self__, "status", status)
        if tags is not None:
            pulumi.set(__self__, "tags", tags)
        if transit_router_attachment_id is not None:
            pulumi.set(__self__, "transit_router_attachment_id", transit_router_attachment_id)
        if transit_router_attachment_name is not None:
            pulumi.set(__self__, "transit_router_attachment_name", transit_router_attachment_name)
        if transit_router_id is not None:
            pulumi.set(__self__, "transit_router_id", transit_router_id)
        if updated_time is not None:
            pulumi.set(__self__, "updated_time", updated_time)
        if vpc_id is not None:
            pulumi.set(__self__, "vpc_id", vpc_id)

    @property
    @pulumi.getter(name="applianceModeEnabled")
    def appliance_mode_enabled(self) -> Optional[pulumi.Input[builtins.bool]]:
        """
        是否启动路径一致模式。请严格按照以下枚举值的大小写输入，不要传入其他取值。true：是。开启后，TR转发流量至该VPC连接时，将选择相同的可用区连接点转发请求流量和返回流量。false：否。
        """
        return pulumi.get(self, "appliance_mode_enabled")

    @appliance_mode_enabled.setter
    def appliance_mode_enabled(self, value: Optional[pulumi.Input[builtins.bool]]):
        pulumi.set(self, "appliance_mode_enabled", value)

    @property
    @pulumi.getter(name="attachPoints")
    def attach_points(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['VpcAttachmentAttachPointArgs']]]]:
        return pulumi.get(self, "attach_points")

    @attach_points.setter
    def attach_points(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['VpcAttachmentAttachPointArgs']]]]):
        pulumi.set(self, "attach_points", value)

    @property
    @pulumi.getter(name="autoPublishRouteEnabled")
    def auto_publish_route_enabled(self) -> Optional[pulumi.Input[builtins.bool]]:
        """
        是否自动同步TR路由到网络实例路由表中。请严格按照以下枚举值的大小写输入，不要传入其他取值。true：是，表示系统会自动同步该网络实例连接关联转发的TR路由表中的路由条目到网络实例的路由表中，仅当该参数配置为true，且网络实例连接关联转发的TR路由表中存在路由条目时，系统才会自动同步TR路由到网络实例的路由表中。false（默认值）：否。
        """
        return pulumi.get(self, "auto_publish_route_enabled")

    @auto_publish_route_enabled.setter
    def auto_publish_route_enabled(self, value: Optional[pulumi.Input[builtins.bool]]):
        pulumi.set(self, "auto_publish_route_enabled", value)

    @property
    @pulumi.getter
    def bandwidth(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        网络实例连接的带宽上限，单位为Gbps。
        """
        return pulumi.get(self, "bandwidth")

    @bandwidth.setter
    def bandwidth(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "bandwidth", value)

    @property
    @pulumi.getter(name="createdTime")
    def created_time(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        创建时间。
        """
        return pulumi.get(self, "created_time")

    @created_time.setter
    def created_time(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "created_time", value)

    @property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        网络实例连接的描述信息。必须以字母、数字或中文开头，可包含字母、数字、中文和以下特殊字符：英文逗号（,）、点号（.）、下划线（_）、空格（ ）、等号（=）、短横线（-）、中文逗号（，）、中文句号（。）。长度限制为0 ~ 255个字符。不传入该参数或该参数不传入数值时，默认为空字符串。
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "description", value)

    @property
    @pulumi.getter(name="ipv6Enabled")
    def ipv6_enabled(self) -> Optional[pulumi.Input[builtins.bool]]:
        """
        是否开启IPv6功能。请严格按照以下枚举值的大小写输入，不要传入其他取值。true：是。false：否。
        """
        return pulumi.get(self, "ipv6_enabled")

    @ipv6_enabled.setter
    def ipv6_enabled(self, value: Optional[pulumi.Input[builtins.bool]]):
        pulumi.set(self, "ipv6_enabled", value)

    @property
    @pulumi.getter
    def status(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        网络实例连接的状态。Creating: 创建中。Deleting: 删除中。Pending：配置中。Available：可用。
        """
        return pulumi.get(self, "status")

    @status.setter
    def status(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "status", value)

    @property
    @pulumi.getter
    def tags(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['VpcAttachmentTagArgs']]]]:
        return pulumi.get(self, "tags")

    @tags.setter
    def tags(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['VpcAttachmentTagArgs']]]]):
        pulumi.set(self, "tags", value)

    @property
    @pulumi.getter(name="transitRouterAttachmentId")
    def transit_router_attachment_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        网络实例连接的ID。
        """
        return pulumi.get(self, "transit_router_attachment_id")

    @transit_router_attachment_id.setter
    def transit_router_attachment_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "transit_router_attachment_id", value)

    @property
    @pulumi.getter(name="transitRouterAttachmentName")
    def transit_router_attachment_name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        网络实例连接的名称。必须以字母、数字或中文开头，可包含字母、数字、中文和以下特殊字符：点号（.）、下划线（_）和短横线（-）。长度限制为1 ~ 128个字符。不传入该参数或该参数不传入数值时，默认为网络实例连接的ID。
        """
        return pulumi.get(self, "transit_router_attachment_name")

    @transit_router_attachment_name.setter
    def transit_router_attachment_name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "transit_router_attachment_name", value)

    @property
    @pulumi.getter(name="transitRouterId")
    def transit_router_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        中转路由器实例的ID。
        """
        return pulumi.get(self, "transit_router_id")

    @transit_router_id.setter
    def transit_router_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "transit_router_id", value)

    @property
    @pulumi.getter(name="updatedTime")
    def updated_time(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        更新时间。
        """
        return pulumi.get(self, "updated_time")

    @updated_time.setter
    def updated_time(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "updated_time", value)

    @property
    @pulumi.getter(name="vpcId")
    def vpc_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        私有网络实例的ID。
        """
        return pulumi.get(self, "vpc_id")

    @vpc_id.setter
    def vpc_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "vpc_id", value)


@pulumi.type_token("bytepluscc:transitrouter/vpcAttachment:VpcAttachment")
class VpcAttachment(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 appliance_mode_enabled: Optional[pulumi.Input[builtins.bool]] = None,
                 attach_points: Optional[pulumi.Input[Sequence[pulumi.Input[Union['VpcAttachmentAttachPointArgs', 'VpcAttachmentAttachPointArgsDict']]]]] = None,
                 auto_publish_route_enabled: Optional[pulumi.Input[builtins.bool]] = None,
                 description: Optional[pulumi.Input[builtins.str]] = None,
                 ipv6_enabled: Optional[pulumi.Input[builtins.bool]] = None,
                 tags: Optional[pulumi.Input[Sequence[pulumi.Input[Union['VpcAttachmentTagArgs', 'VpcAttachmentTagArgsDict']]]]] = None,
                 transit_router_attachment_name: Optional[pulumi.Input[builtins.str]] = None,
                 transit_router_id: Optional[pulumi.Input[builtins.str]] = None,
                 vpc_id: Optional[pulumi.Input[builtins.str]] = None,
                 __props__=None):
        """
        通过在私有网络和中转路由器之间建立连接，可以实现私有网络与中转路由器的私网互通。

        ## Import

        ```sh
        $ pulumi import bytepluscc:transitrouter/vpcAttachment:VpcAttachment example "transit_router_id|transit_router_attachment_id"
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.bool] appliance_mode_enabled: 是否启动路径一致模式。请严格按照以下枚举值的大小写输入，不要传入其他取值。true：是。开启后，TR转发流量至该VPC连接时，将选择相同的可用区连接点转发请求流量和返回流量。false：否。
        :param pulumi.Input[builtins.bool] auto_publish_route_enabled: 是否自动同步TR路由到网络实例路由表中。请严格按照以下枚举值的大小写输入，不要传入其他取值。true：是，表示系统会自动同步该网络实例连接关联转发的TR路由表中的路由条目到网络实例的路由表中，仅当该参数配置为true，且网络实例连接关联转发的TR路由表中存在路由条目时，系统才会自动同步TR路由到网络实例的路由表中。false（默认值）：否。
        :param pulumi.Input[builtins.str] description: 网络实例连接的描述信息。必须以字母、数字或中文开头，可包含字母、数字、中文和以下特殊字符：英文逗号（,）、点号（.）、下划线（_）、空格（ ）、等号（=）、短横线（-）、中文逗号（，）、中文句号（。）。长度限制为0 ~ 255个字符。不传入该参数或该参数不传入数值时，默认为空字符串。
        :param pulumi.Input[builtins.bool] ipv6_enabled: 是否开启IPv6功能。请严格按照以下枚举值的大小写输入，不要传入其他取值。true：是。false：否。
        :param pulumi.Input[builtins.str] transit_router_attachment_name: 网络实例连接的名称。必须以字母、数字或中文开头，可包含字母、数字、中文和以下特殊字符：点号（.）、下划线（_）和短横线（-）。长度限制为1 ~ 128个字符。不传入该参数或该参数不传入数值时，默认为网络实例连接的ID。
        :param pulumi.Input[builtins.str] transit_router_id: 中转路由器实例的ID。
        :param pulumi.Input[builtins.str] vpc_id: 私有网络实例的ID。
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: VpcAttachmentArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        通过在私有网络和中转路由器之间建立连接，可以实现私有网络与中转路由器的私网互通。

        ## Import

        ```sh
        $ pulumi import bytepluscc:transitrouter/vpcAttachment:VpcAttachment example "transit_router_id|transit_router_attachment_id"
        ```

        :param str resource_name: The name of the resource.
        :param VpcAttachmentArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(VpcAttachmentArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 appliance_mode_enabled: Optional[pulumi.Input[builtins.bool]] = None,
                 attach_points: Optional[pulumi.Input[Sequence[pulumi.Input[Union['VpcAttachmentAttachPointArgs', 'VpcAttachmentAttachPointArgsDict']]]]] = None,
                 auto_publish_route_enabled: Optional[pulumi.Input[builtins.bool]] = None,
                 description: Optional[pulumi.Input[builtins.str]] = None,
                 ipv6_enabled: Optional[pulumi.Input[builtins.bool]] = None,
                 tags: Optional[pulumi.Input[Sequence[pulumi.Input[Union['VpcAttachmentTagArgs', 'VpcAttachmentTagArgsDict']]]]] = None,
                 transit_router_attachment_name: Optional[pulumi.Input[builtins.str]] = None,
                 transit_router_id: Optional[pulumi.Input[builtins.str]] = None,
                 vpc_id: Optional[pulumi.Input[builtins.str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = VpcAttachmentArgs.__new__(VpcAttachmentArgs)

            __props__.__dict__["appliance_mode_enabled"] = appliance_mode_enabled
            if attach_points is None and not opts.urn:
                raise TypeError("Missing required property 'attach_points'")
            __props__.__dict__["attach_points"] = attach_points
            __props__.__dict__["auto_publish_route_enabled"] = auto_publish_route_enabled
            __props__.__dict__["description"] = description
            __props__.__dict__["ipv6_enabled"] = ipv6_enabled
            __props__.__dict__["tags"] = tags
            __props__.__dict__["transit_router_attachment_name"] = transit_router_attachment_name
            if transit_router_id is None and not opts.urn:
                raise TypeError("Missing required property 'transit_router_id'")
            __props__.__dict__["transit_router_id"] = transit_router_id
            if vpc_id is None and not opts.urn:
                raise TypeError("Missing required property 'vpc_id'")
            __props__.__dict__["vpc_id"] = vpc_id
            __props__.__dict__["bandwidth"] = None
            __props__.__dict__["created_time"] = None
            __props__.__dict__["status"] = None
            __props__.__dict__["transit_router_attachment_id"] = None
            __props__.__dict__["updated_time"] = None
        super(VpcAttachment, __self__).__init__(
            'bytepluscc:transitrouter/vpcAttachment:VpcAttachment',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            appliance_mode_enabled: Optional[pulumi.Input[builtins.bool]] = None,
            attach_points: Optional[pulumi.Input[Sequence[pulumi.Input[Union['VpcAttachmentAttachPointArgs', 'VpcAttachmentAttachPointArgsDict']]]]] = None,
            auto_publish_route_enabled: Optional[pulumi.Input[builtins.bool]] = None,
            bandwidth: Optional[pulumi.Input[builtins.int]] = None,
            created_time: Optional[pulumi.Input[builtins.str]] = None,
            description: Optional[pulumi.Input[builtins.str]] = None,
            ipv6_enabled: Optional[pulumi.Input[builtins.bool]] = None,
            status: Optional[pulumi.Input[builtins.str]] = None,
            tags: Optional[pulumi.Input[Sequence[pulumi.Input[Union['VpcAttachmentTagArgs', 'VpcAttachmentTagArgsDict']]]]] = None,
            transit_router_attachment_id: Optional[pulumi.Input[builtins.str]] = None,
            transit_router_attachment_name: Optional[pulumi.Input[builtins.str]] = None,
            transit_router_id: Optional[pulumi.Input[builtins.str]] = None,
            updated_time: Optional[pulumi.Input[builtins.str]] = None,
            vpc_id: Optional[pulumi.Input[builtins.str]] = None) -> 'VpcAttachment':
        """
        Get an existing VpcAttachment resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.bool] appliance_mode_enabled: 是否启动路径一致模式。请严格按照以下枚举值的大小写输入，不要传入其他取值。true：是。开启后，TR转发流量至该VPC连接时，将选择相同的可用区连接点转发请求流量和返回流量。false：否。
        :param pulumi.Input[builtins.bool] auto_publish_route_enabled: 是否自动同步TR路由到网络实例路由表中。请严格按照以下枚举值的大小写输入，不要传入其他取值。true：是，表示系统会自动同步该网络实例连接关联转发的TR路由表中的路由条目到网络实例的路由表中，仅当该参数配置为true，且网络实例连接关联转发的TR路由表中存在路由条目时，系统才会自动同步TR路由到网络实例的路由表中。false（默认值）：否。
        :param pulumi.Input[builtins.int] bandwidth: 网络实例连接的带宽上限，单位为Gbps。
        :param pulumi.Input[builtins.str] created_time: 创建时间。
        :param pulumi.Input[builtins.str] description: 网络实例连接的描述信息。必须以字母、数字或中文开头，可包含字母、数字、中文和以下特殊字符：英文逗号（,）、点号（.）、下划线（_）、空格（ ）、等号（=）、短横线（-）、中文逗号（，）、中文句号（。）。长度限制为0 ~ 255个字符。不传入该参数或该参数不传入数值时，默认为空字符串。
        :param pulumi.Input[builtins.bool] ipv6_enabled: 是否开启IPv6功能。请严格按照以下枚举值的大小写输入，不要传入其他取值。true：是。false：否。
        :param pulumi.Input[builtins.str] status: 网络实例连接的状态。Creating: 创建中。Deleting: 删除中。Pending：配置中。Available：可用。
        :param pulumi.Input[builtins.str] transit_router_attachment_id: 网络实例连接的ID。
        :param pulumi.Input[builtins.str] transit_router_attachment_name: 网络实例连接的名称。必须以字母、数字或中文开头，可包含字母、数字、中文和以下特殊字符：点号（.）、下划线（_）和短横线（-）。长度限制为1 ~ 128个字符。不传入该参数或该参数不传入数值时，默认为网络实例连接的ID。
        :param pulumi.Input[builtins.str] transit_router_id: 中转路由器实例的ID。
        :param pulumi.Input[builtins.str] updated_time: 更新时间。
        :param pulumi.Input[builtins.str] vpc_id: 私有网络实例的ID。
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _VpcAttachmentState.__new__(_VpcAttachmentState)

        __props__.__dict__["appliance_mode_enabled"] = appliance_mode_enabled
        __props__.__dict__["attach_points"] = attach_points
        __props__.__dict__["auto_publish_route_enabled"] = auto_publish_route_enabled
        __props__.__dict__["bandwidth"] = bandwidth
        __props__.__dict__["created_time"] = created_time
        __props__.__dict__["description"] = description
        __props__.__dict__["ipv6_enabled"] = ipv6_enabled
        __props__.__dict__["status"] = status
        __props__.__dict__["tags"] = tags
        __props__.__dict__["transit_router_attachment_id"] = transit_router_attachment_id
        __props__.__dict__["transit_router_attachment_name"] = transit_router_attachment_name
        __props__.__dict__["transit_router_id"] = transit_router_id
        __props__.__dict__["updated_time"] = updated_time
        __props__.__dict__["vpc_id"] = vpc_id
        return VpcAttachment(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="applianceModeEnabled")
    def appliance_mode_enabled(self) -> pulumi.Output[builtins.bool]:
        """
        是否启动路径一致模式。请严格按照以下枚举值的大小写输入，不要传入其他取值。true：是。开启后，TR转发流量至该VPC连接时，将选择相同的可用区连接点转发请求流量和返回流量。false：否。
        """
        return pulumi.get(self, "appliance_mode_enabled")

    @property
    @pulumi.getter(name="attachPoints")
    def attach_points(self) -> pulumi.Output[Sequence['outputs.VpcAttachmentAttachPoint']]:
        return pulumi.get(self, "attach_points")

    @property
    @pulumi.getter(name="autoPublishRouteEnabled")
    def auto_publish_route_enabled(self) -> pulumi.Output[builtins.bool]:
        """
        是否自动同步TR路由到网络实例路由表中。请严格按照以下枚举值的大小写输入，不要传入其他取值。true：是，表示系统会自动同步该网络实例连接关联转发的TR路由表中的路由条目到网络实例的路由表中，仅当该参数配置为true，且网络实例连接关联转发的TR路由表中存在路由条目时，系统才会自动同步TR路由到网络实例的路由表中。false（默认值）：否。
        """
        return pulumi.get(self, "auto_publish_route_enabled")

    @property
    @pulumi.getter
    def bandwidth(self) -> pulumi.Output[builtins.int]:
        """
        网络实例连接的带宽上限，单位为Gbps。
        """
        return pulumi.get(self, "bandwidth")

    @property
    @pulumi.getter(name="createdTime")
    def created_time(self) -> pulumi.Output[builtins.str]:
        """
        创建时间。
        """
        return pulumi.get(self, "created_time")

    @property
    @pulumi.getter
    def description(self) -> pulumi.Output[builtins.str]:
        """
        网络实例连接的描述信息。必须以字母、数字或中文开头，可包含字母、数字、中文和以下特殊字符：英文逗号（,）、点号（.）、下划线（_）、空格（ ）、等号（=）、短横线（-）、中文逗号（，）、中文句号（。）。长度限制为0 ~ 255个字符。不传入该参数或该参数不传入数值时，默认为空字符串。
        """
        return pulumi.get(self, "description")

    @property
    @pulumi.getter(name="ipv6Enabled")
    def ipv6_enabled(self) -> pulumi.Output[builtins.bool]:
        """
        是否开启IPv6功能。请严格按照以下枚举值的大小写输入，不要传入其他取值。true：是。false：否。
        """
        return pulumi.get(self, "ipv6_enabled")

    @property
    @pulumi.getter
    def status(self) -> pulumi.Output[builtins.str]:
        """
        网络实例连接的状态。Creating: 创建中。Deleting: 删除中。Pending：配置中。Available：可用。
        """
        return pulumi.get(self, "status")

    @property
    @pulumi.getter
    def tags(self) -> pulumi.Output[Sequence['outputs.VpcAttachmentTag']]:
        return pulumi.get(self, "tags")

    @property
    @pulumi.getter(name="transitRouterAttachmentId")
    def transit_router_attachment_id(self) -> pulumi.Output[builtins.str]:
        """
        网络实例连接的ID。
        """
        return pulumi.get(self, "transit_router_attachment_id")

    @property
    @pulumi.getter(name="transitRouterAttachmentName")
    def transit_router_attachment_name(self) -> pulumi.Output[builtins.str]:
        """
        网络实例连接的名称。必须以字母、数字或中文开头，可包含字母、数字、中文和以下特殊字符：点号（.）、下划线（_）和短横线（-）。长度限制为1 ~ 128个字符。不传入该参数或该参数不传入数值时，默认为网络实例连接的ID。
        """
        return pulumi.get(self, "transit_router_attachment_name")

    @property
    @pulumi.getter(name="transitRouterId")
    def transit_router_id(self) -> pulumi.Output[builtins.str]:
        """
        中转路由器实例的ID。
        """
        return pulumi.get(self, "transit_router_id")

    @property
    @pulumi.getter(name="updatedTime")
    def updated_time(self) -> pulumi.Output[builtins.str]:
        """
        更新时间。
        """
        return pulumi.get(self, "updated_time")

    @property
    @pulumi.getter(name="vpcId")
    def vpc_id(self) -> pulumi.Output[builtins.str]:
        """
        私有网络实例的ID。
        """
        return pulumi.get(self, "vpc_id")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs
from ._inputs import *

__all__ = ['FlowLogArgs', 'FlowLog']

@pulumi.input_type
class FlowLogArgs:
    def __init__(__self__, *,
                 aggregation_interval: pulumi.Input[builtins.int],
                 flow_log_name: pulumi.Input[builtins.str],
                 log_project_name: pulumi.Input[builtins.str],
                 log_topic_name: pulumi.Input[builtins.str],
                 resource_id: pulumi.Input[builtins.str],
                 resource_type: pulumi.Input[builtins.str],
                 traffic_type: pulumi.Input[builtins.str],
                 description: Optional[pulumi.Input[builtins.str]] = None,
                 project_name: Optional[pulumi.Input[builtins.str]] = None,
                 status: Optional[pulumi.Input[builtins.str]] = None,
                 tags: Optional[pulumi.Input[Sequence[pulumi.Input['FlowLogTagArgs']]]] = None):
        """
        The set of arguments for constructing a FlowLog resource.
        :param pulumi.Input[builtins.int] aggregation_interval: 流日志的采样间隔。取值如下。1：1分钟。5：5分钟。10（默认值）：10分钟。
        :param pulumi.Input[builtins.str] flow_log_name: 流日志的名称。长度限制为1 ~ 128个字符。需要以字母、中文或数字开头，可包含点号（.）、下划线（_）和短横线（-）。不填默认为流日志实例的ID。
        :param pulumi.Input[builtins.str] log_project_name: 流日志项目的名称。名称只能由小写字母、数字和连字符（-）组成。必须以小写字母或者数字开头和结尾。名称的长度范围为 3~63 个字符。
        :param pulumi.Input[builtins.str] log_topic_name: 流日志项目的名称。名称只能由小写字母、数字和连字符（-）组成。必须以小写字母或者数字开头和结尾。名称的长度范围为 3~63 个字符。
        :param pulumi.Input[builtins.str] resource_id: 要捕获流量的资源ID。
        :param pulumi.Input[builtins.str] resource_type: 要采集流量的资源类型，取值如下：vpc：私有网络。subnet：子网。eni：网卡。
        :param pulumi.Input[builtins.str] traffic_type: 采集的流量类型。取值如下：All：全部流量。Allow：网络ACL和安全组允许的流量。Drop：网络ACL和安全组拒绝的流量。
        :param pulumi.Input[builtins.str] description: 流日志的描述信息。长度限制为0~ 255个字符。不填默认为空字符串。需要以字母、中文或数字开头。可包含英文逗号（,）、点号（.）、下划线（_）、空格（ ）、等号（=）、短横线（-）、中文逗号（，）、中文句号（。）。
        :param pulumi.Input[builtins.str] project_name: 流流日志所属项目的名称。
        :param pulumi.Input[builtins.str] status: 流日志的状态。取值如下：Active：启动状态。Pending：正在操作中。Inactive：未启动状态。Creating：正在创建中。Deleting：正在删除中。
        """
        pulumi.set(__self__, "aggregation_interval", aggregation_interval)
        pulumi.set(__self__, "flow_log_name", flow_log_name)
        pulumi.set(__self__, "log_project_name", log_project_name)
        pulumi.set(__self__, "log_topic_name", log_topic_name)
        pulumi.set(__self__, "resource_id", resource_id)
        pulumi.set(__self__, "resource_type", resource_type)
        pulumi.set(__self__, "traffic_type", traffic_type)
        if description is not None:
            pulumi.set(__self__, "description", description)
        if project_name is not None:
            pulumi.set(__self__, "project_name", project_name)
        if status is not None:
            pulumi.set(__self__, "status", status)
        if tags is not None:
            pulumi.set(__self__, "tags", tags)

    @property
    @pulumi.getter(name="aggregationInterval")
    def aggregation_interval(self) -> pulumi.Input[builtins.int]:
        """
        流日志的采样间隔。取值如下。1：1分钟。5：5分钟。10（默认值）：10分钟。
        """
        return pulumi.get(self, "aggregation_interval")

    @aggregation_interval.setter
    def aggregation_interval(self, value: pulumi.Input[builtins.int]):
        pulumi.set(self, "aggregation_interval", value)

    @property
    @pulumi.getter(name="flowLogName")
    def flow_log_name(self) -> pulumi.Input[builtins.str]:
        """
        流日志的名称。长度限制为1 ~ 128个字符。需要以字母、中文或数字开头，可包含点号（.）、下划线（_）和短横线（-）。不填默认为流日志实例的ID。
        """
        return pulumi.get(self, "flow_log_name")

    @flow_log_name.setter
    def flow_log_name(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "flow_log_name", value)

    @property
    @pulumi.getter(name="logProjectName")
    def log_project_name(self) -> pulumi.Input[builtins.str]:
        """
        流日志项目的名称。名称只能由小写字母、数字和连字符（-）组成。必须以小写字母或者数字开头和结尾。名称的长度范围为 3~63 个字符。
        """
        return pulumi.get(self, "log_project_name")

    @log_project_name.setter
    def log_project_name(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "log_project_name", value)

    @property
    @pulumi.getter(name="logTopicName")
    def log_topic_name(self) -> pulumi.Input[builtins.str]:
        """
        流日志项目的名称。名称只能由小写字母、数字和连字符（-）组成。必须以小写字母或者数字开头和结尾。名称的长度范围为 3~63 个字符。
        """
        return pulumi.get(self, "log_topic_name")

    @log_topic_name.setter
    def log_topic_name(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "log_topic_name", value)

    @property
    @pulumi.getter(name="resourceId")
    def resource_id(self) -> pulumi.Input[builtins.str]:
        """
        要捕获流量的资源ID。
        """
        return pulumi.get(self, "resource_id")

    @resource_id.setter
    def resource_id(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "resource_id", value)

    @property
    @pulumi.getter(name="resourceType")
    def resource_type(self) -> pulumi.Input[builtins.str]:
        """
        要采集流量的资源类型，取值如下：vpc：私有网络。subnet：子网。eni：网卡。
        """
        return pulumi.get(self, "resource_type")

    @resource_type.setter
    def resource_type(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "resource_type", value)

    @property
    @pulumi.getter(name="trafficType")
    def traffic_type(self) -> pulumi.Input[builtins.str]:
        """
        采集的流量类型。取值如下：All：全部流量。Allow：网络ACL和安全组允许的流量。Drop：网络ACL和安全组拒绝的流量。
        """
        return pulumi.get(self, "traffic_type")

    @traffic_type.setter
    def traffic_type(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "traffic_type", value)

    @property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        流日志的描述信息。长度限制为0~ 255个字符。不填默认为空字符串。需要以字母、中文或数字开头。可包含英文逗号（,）、点号（.）、下划线（_）、空格（ ）、等号（=）、短横线（-）、中文逗号（，）、中文句号（。）。
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "description", value)

    @property
    @pulumi.getter(name="projectName")
    def project_name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        流流日志所属项目的名称。
        """
        return pulumi.get(self, "project_name")

    @project_name.setter
    def project_name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "project_name", value)

    @property
    @pulumi.getter
    def status(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        流日志的状态。取值如下：Active：启动状态。Pending：正在操作中。Inactive：未启动状态。Creating：正在创建中。Deleting：正在删除中。
        """
        return pulumi.get(self, "status")

    @status.setter
    def status(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "status", value)

    @property
    @pulumi.getter
    def tags(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['FlowLogTagArgs']]]]:
        return pulumi.get(self, "tags")

    @tags.setter
    def tags(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['FlowLogTagArgs']]]]):
        pulumi.set(self, "tags", value)


@pulumi.input_type
class _FlowLogState:
    def __init__(__self__, *,
                 aggregation_interval: Optional[pulumi.Input[builtins.int]] = None,
                 business_status: Optional[pulumi.Input[builtins.str]] = None,
                 created_at: Optional[pulumi.Input[builtins.str]] = None,
                 description: Optional[pulumi.Input[builtins.str]] = None,
                 enable_index: Optional[pulumi.Input[builtins.bool]] = None,
                 flow_log_id: Optional[pulumi.Input[builtins.str]] = None,
                 flow_log_name: Optional[pulumi.Input[builtins.str]] = None,
                 lock_reason: Optional[pulumi.Input[builtins.str]] = None,
                 log_project_id: Optional[pulumi.Input[builtins.str]] = None,
                 log_project_name: Optional[pulumi.Input[builtins.str]] = None,
                 log_topic_id: Optional[pulumi.Input[builtins.str]] = None,
                 log_topic_name: Optional[pulumi.Input[builtins.str]] = None,
                 project_name: Optional[pulumi.Input[builtins.str]] = None,
                 resource_id: Optional[pulumi.Input[builtins.str]] = None,
                 resource_type: Optional[pulumi.Input[builtins.str]] = None,
                 status: Optional[pulumi.Input[builtins.str]] = None,
                 tags: Optional[pulumi.Input[Sequence[pulumi.Input['FlowLogTagArgs']]]] = None,
                 traffic_type: Optional[pulumi.Input[builtins.str]] = None,
                 updated_at: Optional[pulumi.Input[builtins.str]] = None,
                 vpc_id: Optional[pulumi.Input[builtins.str]] = None):
        """
        Input properties used for looking up and filtering FlowLog resources.
        :param pulumi.Input[builtins.int] aggregation_interval: 流日志的采样间隔。取值如下。1：1分钟。5：5分钟。10（默认值）：10分钟。
        :param pulumi.Input[builtins.str] business_status: 流日志是否被锁定。Normal: 正常。FinancialLocked: 被锁定。
        :param pulumi.Input[builtins.str] created_at: 流日志的创建时间。
        :param pulumi.Input[builtins.str] description: 流日志的描述信息。长度限制为0~ 255个字符。不填默认为空字符串。需要以字母、中文或数字开头。可包含英文逗号（,）、点号（.）、下划线（_）、空格（ ）、等号（=）、短横线（-）、中文逗号（，）、中文句号（。）。
        :param pulumi.Input[builtins.bool] enable_index: 是否自动配置索引。索引用于检索分析数据，流日志在检索分析之前，必须先配置索引。true：是。false（默认值）：否。
        :param pulumi.Input[builtins.str] flow_log_id: 流日志的ID。
        :param pulumi.Input[builtins.str] flow_log_name: 流日志的名称。长度限制为1 ~ 128个字符。需要以字母、中文或数字开头，可包含点号（.）、下划线（_）和短横线（-）。不填默认为流日志实例的ID。
        :param pulumi.Input[builtins.str] lock_reason: 流日志被锁定的原因。financial: 因欠费被锁定。unlock：欠费关停后充值恢复过程中。空值 : 没有被锁定。
        :param pulumi.Input[builtins.str] log_project_id: 流日志项目的ID。
        :param pulumi.Input[builtins.str] log_project_name: 流日志项目的名称。名称只能由小写字母、数字和连字符（-）组成。必须以小写字母或者数字开头和结尾。名称的长度范围为 3~63 个字符。
        :param pulumi.Input[builtins.str] log_topic_id: 流日志主题的ID。
        :param pulumi.Input[builtins.str] log_topic_name: 流日志项目的名称。名称只能由小写字母、数字和连字符（-）组成。必须以小写字母或者数字开头和结尾。名称的长度范围为 3~63 个字符。
        :param pulumi.Input[builtins.str] project_name: 流流日志所属项目的名称。
        :param pulumi.Input[builtins.str] resource_id: 要捕获流量的资源ID。
        :param pulumi.Input[builtins.str] resource_type: 要采集流量的资源类型，取值如下：vpc：私有网络。subnet：子网。eni：网卡。
        :param pulumi.Input[builtins.str] status: 流日志的状态。取值如下：Active：启动状态。Pending：正在操作中。Inactive：未启动状态。Creating：正在创建中。Deleting：正在删除中。
        :param pulumi.Input[builtins.str] traffic_type: 采集的流量类型。取值如下：All：全部流量。Allow：网络ACL和安全组允许的流量。Drop：网络ACL和安全组拒绝的流量。
        :param pulumi.Input[builtins.str] updated_at: 更新流日志的时间。
        :param pulumi.Input[builtins.str] vpc_id: 流日志的VPC的ID。
        """
        if aggregation_interval is not None:
            pulumi.set(__self__, "aggregation_interval", aggregation_interval)
        if business_status is not None:
            pulumi.set(__self__, "business_status", business_status)
        if created_at is not None:
            pulumi.set(__self__, "created_at", created_at)
        if description is not None:
            pulumi.set(__self__, "description", description)
        if enable_index is not None:
            pulumi.set(__self__, "enable_index", enable_index)
        if flow_log_id is not None:
            pulumi.set(__self__, "flow_log_id", flow_log_id)
        if flow_log_name is not None:
            pulumi.set(__self__, "flow_log_name", flow_log_name)
        if lock_reason is not None:
            pulumi.set(__self__, "lock_reason", lock_reason)
        if log_project_id is not None:
            pulumi.set(__self__, "log_project_id", log_project_id)
        if log_project_name is not None:
            pulumi.set(__self__, "log_project_name", log_project_name)
        if log_topic_id is not None:
            pulumi.set(__self__, "log_topic_id", log_topic_id)
        if log_topic_name is not None:
            pulumi.set(__self__, "log_topic_name", log_topic_name)
        if project_name is not None:
            pulumi.set(__self__, "project_name", project_name)
        if resource_id is not None:
            pulumi.set(__self__, "resource_id", resource_id)
        if resource_type is not None:
            pulumi.set(__self__, "resource_type", resource_type)
        if status is not None:
            pulumi.set(__self__, "status", status)
        if tags is not None:
            pulumi.set(__self__, "tags", tags)
        if traffic_type is not None:
            pulumi.set(__self__, "traffic_type", traffic_type)
        if updated_at is not None:
            pulumi.set(__self__, "updated_at", updated_at)
        if vpc_id is not None:
            pulumi.set(__self__, "vpc_id", vpc_id)

    @property
    @pulumi.getter(name="aggregationInterval")
    def aggregation_interval(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        流日志的采样间隔。取值如下。1：1分钟。5：5分钟。10（默认值）：10分钟。
        """
        return pulumi.get(self, "aggregation_interval")

    @aggregation_interval.setter
    def aggregation_interval(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "aggregation_interval", value)

    @property
    @pulumi.getter(name="businessStatus")
    def business_status(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        流日志是否被锁定。Normal: 正常。FinancialLocked: 被锁定。
        """
        return pulumi.get(self, "business_status")

    @business_status.setter
    def business_status(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "business_status", value)

    @property
    @pulumi.getter(name="createdAt")
    def created_at(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        流日志的创建时间。
        """
        return pulumi.get(self, "created_at")

    @created_at.setter
    def created_at(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "created_at", value)

    @property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        流日志的描述信息。长度限制为0~ 255个字符。不填默认为空字符串。需要以字母、中文或数字开头。可包含英文逗号（,）、点号（.）、下划线（_）、空格（ ）、等号（=）、短横线（-）、中文逗号（，）、中文句号（。）。
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "description", value)

    @property
    @pulumi.getter(name="enableIndex")
    def enable_index(self) -> Optional[pulumi.Input[builtins.bool]]:
        """
        是否自动配置索引。索引用于检索分析数据，流日志在检索分析之前，必须先配置索引。true：是。false（默认值）：否。
        """
        return pulumi.get(self, "enable_index")

    @enable_index.setter
    def enable_index(self, value: Optional[pulumi.Input[builtins.bool]]):
        pulumi.set(self, "enable_index", value)

    @property
    @pulumi.getter(name="flowLogId")
    def flow_log_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        流日志的ID。
        """
        return pulumi.get(self, "flow_log_id")

    @flow_log_id.setter
    def flow_log_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "flow_log_id", value)

    @property
    @pulumi.getter(name="flowLogName")
    def flow_log_name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        流日志的名称。长度限制为1 ~ 128个字符。需要以字母、中文或数字开头，可包含点号（.）、下划线（_）和短横线（-）。不填默认为流日志实例的ID。
        """
        return pulumi.get(self, "flow_log_name")

    @flow_log_name.setter
    def flow_log_name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "flow_log_name", value)

    @property
    @pulumi.getter(name="lockReason")
    def lock_reason(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        流日志被锁定的原因。financial: 因欠费被锁定。unlock：欠费关停后充值恢复过程中。空值 : 没有被锁定。
        """
        return pulumi.get(self, "lock_reason")

    @lock_reason.setter
    def lock_reason(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "lock_reason", value)

    @property
    @pulumi.getter(name="logProjectId")
    def log_project_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        流日志项目的ID。
        """
        return pulumi.get(self, "log_project_id")

    @log_project_id.setter
    def log_project_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "log_project_id", value)

    @property
    @pulumi.getter(name="logProjectName")
    def log_project_name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        流日志项目的名称。名称只能由小写字母、数字和连字符（-）组成。必须以小写字母或者数字开头和结尾。名称的长度范围为 3~63 个字符。
        """
        return pulumi.get(self, "log_project_name")

    @log_project_name.setter
    def log_project_name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "log_project_name", value)

    @property
    @pulumi.getter(name="logTopicId")
    def log_topic_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        流日志主题的ID。
        """
        return pulumi.get(self, "log_topic_id")

    @log_topic_id.setter
    def log_topic_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "log_topic_id", value)

    @property
    @pulumi.getter(name="logTopicName")
    def log_topic_name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        流日志项目的名称。名称只能由小写字母、数字和连字符（-）组成。必须以小写字母或者数字开头和结尾。名称的长度范围为 3~63 个字符。
        """
        return pulumi.get(self, "log_topic_name")

    @log_topic_name.setter
    def log_topic_name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "log_topic_name", value)

    @property
    @pulumi.getter(name="projectName")
    def project_name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        流流日志所属项目的名称。
        """
        return pulumi.get(self, "project_name")

    @project_name.setter
    def project_name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "project_name", value)

    @property
    @pulumi.getter(name="resourceId")
    def resource_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        要捕获流量的资源ID。
        """
        return pulumi.get(self, "resource_id")

    @resource_id.setter
    def resource_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "resource_id", value)

    @property
    @pulumi.getter(name="resourceType")
    def resource_type(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        要采集流量的资源类型，取值如下：vpc：私有网络。subnet：子网。eni：网卡。
        """
        return pulumi.get(self, "resource_type")

    @resource_type.setter
    def resource_type(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "resource_type", value)

    @property
    @pulumi.getter
    def status(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        流日志的状态。取值如下：Active：启动状态。Pending：正在操作中。Inactive：未启动状态。Creating：正在创建中。Deleting：正在删除中。
        """
        return pulumi.get(self, "status")

    @status.setter
    def status(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "status", value)

    @property
    @pulumi.getter
    def tags(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['FlowLogTagArgs']]]]:
        return pulumi.get(self, "tags")

    @tags.setter
    def tags(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['FlowLogTagArgs']]]]):
        pulumi.set(self, "tags", value)

    @property
    @pulumi.getter(name="trafficType")
    def traffic_type(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        采集的流量类型。取值如下：All：全部流量。Allow：网络ACL和安全组允许的流量。Drop：网络ACL和安全组拒绝的流量。
        """
        return pulumi.get(self, "traffic_type")

    @traffic_type.setter
    def traffic_type(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "traffic_type", value)

    @property
    @pulumi.getter(name="updatedAt")
    def updated_at(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        更新流日志的时间。
        """
        return pulumi.get(self, "updated_at")

    @updated_at.setter
    def updated_at(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "updated_at", value)

    @property
    @pulumi.getter(name="vpcId")
    def vpc_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        流日志的VPC的ID。
        """
        return pulumi.get(self, "vpc_id")

    @vpc_id.setter
    def vpc_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "vpc_id", value)


@pulumi.type_token("bytepluscc:vpc/flowLog:FlowLog")
class FlowLog(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 aggregation_interval: Optional[pulumi.Input[builtins.int]] = None,
                 description: Optional[pulumi.Input[builtins.str]] = None,
                 flow_log_name: Optional[pulumi.Input[builtins.str]] = None,
                 log_project_name: Optional[pulumi.Input[builtins.str]] = None,
                 log_topic_name: Optional[pulumi.Input[builtins.str]] = None,
                 project_name: Optional[pulumi.Input[builtins.str]] = None,
                 resource_id: Optional[pulumi.Input[builtins.str]] = None,
                 resource_type: Optional[pulumi.Input[builtins.str]] = None,
                 status: Optional[pulumi.Input[builtins.str]] = None,
                 tags: Optional[pulumi.Input[Sequence[pulumi.Input[Union['FlowLogTagArgs', 'FlowLogTagArgsDict']]]]] = None,
                 traffic_type: Optional[pulumi.Input[builtins.str]] = None,
                 __props__=None):
        """
        流日志对网卡出入流量的日志数据按需聚合处理后，投递至 日志服务 存储和检索分析，您可以根据流日志的分析监控网络流量、排查网络问题、优化网络架构。VPC流日志记录VPC网络流量的详细信息，用于网络监控、流量分析和故障排查。

        ## Example Usage

        ```python
        import pulumi
        import pulumi_bytepluscc as bytepluscc

        v_pc_flow_log_demo = bytepluscc.vpc.FlowLog("VPCFlowLogDemo",
            aggregation_interval=10,
            description="this is a test flow log",
            flow_log_name="FlowLog-ccapi-test",
            log_project_name="ccapi-test-flow-log",
            log_topic_name="test-flow-log",
            project_name="default",
            resource_id="vpc-rrco37ovjq4gv0xxxxxx",
            resource_type="vpc",
            status="Active",
            tags=[{
                "key": "env",
                "value": "test",
            }],
            traffic_type="All")
        ```

        ## Import

        ```sh
        $ pulumi import bytepluscc:vpc/flowLog:FlowLog example "flow_log_id"
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.int] aggregation_interval: 流日志的采样间隔。取值如下。1：1分钟。5：5分钟。10（默认值）：10分钟。
        :param pulumi.Input[builtins.str] description: 流日志的描述信息。长度限制为0~ 255个字符。不填默认为空字符串。需要以字母、中文或数字开头。可包含英文逗号（,）、点号（.）、下划线（_）、空格（ ）、等号（=）、短横线（-）、中文逗号（，）、中文句号（。）。
        :param pulumi.Input[builtins.str] flow_log_name: 流日志的名称。长度限制为1 ~ 128个字符。需要以字母、中文或数字开头，可包含点号（.）、下划线（_）和短横线（-）。不填默认为流日志实例的ID。
        :param pulumi.Input[builtins.str] log_project_name: 流日志项目的名称。名称只能由小写字母、数字和连字符（-）组成。必须以小写字母或者数字开头和结尾。名称的长度范围为 3~63 个字符。
        :param pulumi.Input[builtins.str] log_topic_name: 流日志项目的名称。名称只能由小写字母、数字和连字符（-）组成。必须以小写字母或者数字开头和结尾。名称的长度范围为 3~63 个字符。
        :param pulumi.Input[builtins.str] project_name: 流流日志所属项目的名称。
        :param pulumi.Input[builtins.str] resource_id: 要捕获流量的资源ID。
        :param pulumi.Input[builtins.str] resource_type: 要采集流量的资源类型，取值如下：vpc：私有网络。subnet：子网。eni：网卡。
        :param pulumi.Input[builtins.str] status: 流日志的状态。取值如下：Active：启动状态。Pending：正在操作中。Inactive：未启动状态。Creating：正在创建中。Deleting：正在删除中。
        :param pulumi.Input[builtins.str] traffic_type: 采集的流量类型。取值如下：All：全部流量。Allow：网络ACL和安全组允许的流量。Drop：网络ACL和安全组拒绝的流量。
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: FlowLogArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        流日志对网卡出入流量的日志数据按需聚合处理后，投递至 日志服务 存储和检索分析，您可以根据流日志的分析监控网络流量、排查网络问题、优化网络架构。VPC流日志记录VPC网络流量的详细信息，用于网络监控、流量分析和故障排查。

        ## Example Usage

        ```python
        import pulumi
        import pulumi_bytepluscc as bytepluscc

        v_pc_flow_log_demo = bytepluscc.vpc.FlowLog("VPCFlowLogDemo",
            aggregation_interval=10,
            description="this is a test flow log",
            flow_log_name="FlowLog-ccapi-test",
            log_project_name="ccapi-test-flow-log",
            log_topic_name="test-flow-log",
            project_name="default",
            resource_id="vpc-rrco37ovjq4gv0xxxxxx",
            resource_type="vpc",
            status="Active",
            tags=[{
                "key": "env",
                "value": "test",
            }],
            traffic_type="All")
        ```

        ## Import

        ```sh
        $ pulumi import bytepluscc:vpc/flowLog:FlowLog example "flow_log_id"
        ```

        :param str resource_name: The name of the resource.
        :param FlowLogArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(FlowLogArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 aggregation_interval: Optional[pulumi.Input[builtins.int]] = None,
                 description: Optional[pulumi.Input[builtins.str]] = None,
                 flow_log_name: Optional[pulumi.Input[builtins.str]] = None,
                 log_project_name: Optional[pulumi.Input[builtins.str]] = None,
                 log_topic_name: Optional[pulumi.Input[builtins.str]] = None,
                 project_name: Optional[pulumi.Input[builtins.str]] = None,
                 resource_id: Optional[pulumi.Input[builtins.str]] = None,
                 resource_type: Optional[pulumi.Input[builtins.str]] = None,
                 status: Optional[pulumi.Input[builtins.str]] = None,
                 tags: Optional[pulumi.Input[Sequence[pulumi.Input[Union['FlowLogTagArgs', 'FlowLogTagArgsDict']]]]] = None,
                 traffic_type: Optional[pulumi.Input[builtins.str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = FlowLogArgs.__new__(FlowLogArgs)

            if aggregation_interval is None and not opts.urn:
                raise TypeError("Missing required property 'aggregation_interval'")
            __props__.__dict__["aggregation_interval"] = aggregation_interval
            __props__.__dict__["description"] = description
            if flow_log_name is None and not opts.urn:
                raise TypeError("Missing required property 'flow_log_name'")
            __props__.__dict__["flow_log_name"] = flow_log_name
            if log_project_name is None and not opts.urn:
                raise TypeError("Missing required property 'log_project_name'")
            __props__.__dict__["log_project_name"] = log_project_name
            if log_topic_name is None and not opts.urn:
                raise TypeError("Missing required property 'log_topic_name'")
            __props__.__dict__["log_topic_name"] = log_topic_name
            __props__.__dict__["project_name"] = project_name
            if resource_id is None and not opts.urn:
                raise TypeError("Missing required property 'resource_id'")
            __props__.__dict__["resource_id"] = resource_id
            if resource_type is None and not opts.urn:
                raise TypeError("Missing required property 'resource_type'")
            __props__.__dict__["resource_type"] = resource_type
            __props__.__dict__["status"] = status
            __props__.__dict__["tags"] = tags
            if traffic_type is None and not opts.urn:
                raise TypeError("Missing required property 'traffic_type'")
            __props__.__dict__["traffic_type"] = traffic_type
            __props__.__dict__["business_status"] = None
            __props__.__dict__["created_at"] = None
            __props__.__dict__["enable_index"] = None
            __props__.__dict__["flow_log_id"] = None
            __props__.__dict__["lock_reason"] = None
            __props__.__dict__["log_project_id"] = None
            __props__.__dict__["log_topic_id"] = None
            __props__.__dict__["updated_at"] = None
            __props__.__dict__["vpc_id"] = None
        super(FlowLog, __self__).__init__(
            'bytepluscc:vpc/flowLog:FlowLog',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            aggregation_interval: Optional[pulumi.Input[builtins.int]] = None,
            business_status: Optional[pulumi.Input[builtins.str]] = None,
            created_at: Optional[pulumi.Input[builtins.str]] = None,
            description: Optional[pulumi.Input[builtins.str]] = None,
            enable_index: Optional[pulumi.Input[builtins.bool]] = None,
            flow_log_id: Optional[pulumi.Input[builtins.str]] = None,
            flow_log_name: Optional[pulumi.Input[builtins.str]] = None,
            lock_reason: Optional[pulumi.Input[builtins.str]] = None,
            log_project_id: Optional[pulumi.Input[builtins.str]] = None,
            log_project_name: Optional[pulumi.Input[builtins.str]] = None,
            log_topic_id: Optional[pulumi.Input[builtins.str]] = None,
            log_topic_name: Optional[pulumi.Input[builtins.str]] = None,
            project_name: Optional[pulumi.Input[builtins.str]] = None,
            resource_id: Optional[pulumi.Input[builtins.str]] = None,
            resource_type: Optional[pulumi.Input[builtins.str]] = None,
            status: Optional[pulumi.Input[builtins.str]] = None,
            tags: Optional[pulumi.Input[Sequence[pulumi.Input[Union['FlowLogTagArgs', 'FlowLogTagArgsDict']]]]] = None,
            traffic_type: Optional[pulumi.Input[builtins.str]] = None,
            updated_at: Optional[pulumi.Input[builtins.str]] = None,
            vpc_id: Optional[pulumi.Input[builtins.str]] = None) -> 'FlowLog':
        """
        Get an existing FlowLog resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.int] aggregation_interval: 流日志的采样间隔。取值如下。1：1分钟。5：5分钟。10（默认值）：10分钟。
        :param pulumi.Input[builtins.str] business_status: 流日志是否被锁定。Normal: 正常。FinancialLocked: 被锁定。
        :param pulumi.Input[builtins.str] created_at: 流日志的创建时间。
        :param pulumi.Input[builtins.str] description: 流日志的描述信息。长度限制为0~ 255个字符。不填默认为空字符串。需要以字母、中文或数字开头。可包含英文逗号（,）、点号（.）、下划线（_）、空格（ ）、等号（=）、短横线（-）、中文逗号（，）、中文句号（。）。
        :param pulumi.Input[builtins.bool] enable_index: 是否自动配置索引。索引用于检索分析数据，流日志在检索分析之前，必须先配置索引。true：是。false（默认值）：否。
        :param pulumi.Input[builtins.str] flow_log_id: 流日志的ID。
        :param pulumi.Input[builtins.str] flow_log_name: 流日志的名称。长度限制为1 ~ 128个字符。需要以字母、中文或数字开头，可包含点号（.）、下划线（_）和短横线（-）。不填默认为流日志实例的ID。
        :param pulumi.Input[builtins.str] lock_reason: 流日志被锁定的原因。financial: 因欠费被锁定。unlock：欠费关停后充值恢复过程中。空值 : 没有被锁定。
        :param pulumi.Input[builtins.str] log_project_id: 流日志项目的ID。
        :param pulumi.Input[builtins.str] log_project_name: 流日志项目的名称。名称只能由小写字母、数字和连字符（-）组成。必须以小写字母或者数字开头和结尾。名称的长度范围为 3~63 个字符。
        :param pulumi.Input[builtins.str] log_topic_id: 流日志主题的ID。
        :param pulumi.Input[builtins.str] log_topic_name: 流日志项目的名称。名称只能由小写字母、数字和连字符（-）组成。必须以小写字母或者数字开头和结尾。名称的长度范围为 3~63 个字符。
        :param pulumi.Input[builtins.str] project_name: 流流日志所属项目的名称。
        :param pulumi.Input[builtins.str] resource_id: 要捕获流量的资源ID。
        :param pulumi.Input[builtins.str] resource_type: 要采集流量的资源类型，取值如下：vpc：私有网络。subnet：子网。eni：网卡。
        :param pulumi.Input[builtins.str] status: 流日志的状态。取值如下：Active：启动状态。Pending：正在操作中。Inactive：未启动状态。Creating：正在创建中。Deleting：正在删除中。
        :param pulumi.Input[builtins.str] traffic_type: 采集的流量类型。取值如下：All：全部流量。Allow：网络ACL和安全组允许的流量。Drop：网络ACL和安全组拒绝的流量。
        :param pulumi.Input[builtins.str] updated_at: 更新流日志的时间。
        :param pulumi.Input[builtins.str] vpc_id: 流日志的VPC的ID。
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _FlowLogState.__new__(_FlowLogState)

        __props__.__dict__["aggregation_interval"] = aggregation_interval
        __props__.__dict__["business_status"] = business_status
        __props__.__dict__["created_at"] = created_at
        __props__.__dict__["description"] = description
        __props__.__dict__["enable_index"] = enable_index
        __props__.__dict__["flow_log_id"] = flow_log_id
        __props__.__dict__["flow_log_name"] = flow_log_name
        __props__.__dict__["lock_reason"] = lock_reason
        __props__.__dict__["log_project_id"] = log_project_id
        __props__.__dict__["log_project_name"] = log_project_name
        __props__.__dict__["log_topic_id"] = log_topic_id
        __props__.__dict__["log_topic_name"] = log_topic_name
        __props__.__dict__["project_name"] = project_name
        __props__.__dict__["resource_id"] = resource_id
        __props__.__dict__["resource_type"] = resource_type
        __props__.__dict__["status"] = status
        __props__.__dict__["tags"] = tags
        __props__.__dict__["traffic_type"] = traffic_type
        __props__.__dict__["updated_at"] = updated_at
        __props__.__dict__["vpc_id"] = vpc_id
        return FlowLog(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="aggregationInterval")
    def aggregation_interval(self) -> pulumi.Output[builtins.int]:
        """
        流日志的采样间隔。取值如下。1：1分钟。5：5分钟。10（默认值）：10分钟。
        """
        return pulumi.get(self, "aggregation_interval")

    @property
    @pulumi.getter(name="businessStatus")
    def business_status(self) -> pulumi.Output[builtins.str]:
        """
        流日志是否被锁定。Normal: 正常。FinancialLocked: 被锁定。
        """
        return pulumi.get(self, "business_status")

    @property
    @pulumi.getter(name="createdAt")
    def created_at(self) -> pulumi.Output[builtins.str]:
        """
        流日志的创建时间。
        """
        return pulumi.get(self, "created_at")

    @property
    @pulumi.getter
    def description(self) -> pulumi.Output[builtins.str]:
        """
        流日志的描述信息。长度限制为0~ 255个字符。不填默认为空字符串。需要以字母、中文或数字开头。可包含英文逗号（,）、点号（.）、下划线（_）、空格（ ）、等号（=）、短横线（-）、中文逗号（，）、中文句号（。）。
        """
        return pulumi.get(self, "description")

    @property
    @pulumi.getter(name="enableIndex")
    def enable_index(self) -> pulumi.Output[builtins.bool]:
        """
        是否自动配置索引。索引用于检索分析数据，流日志在检索分析之前，必须先配置索引。true：是。false（默认值）：否。
        """
        return pulumi.get(self, "enable_index")

    @property
    @pulumi.getter(name="flowLogId")
    def flow_log_id(self) -> pulumi.Output[builtins.str]:
        """
        流日志的ID。
        """
        return pulumi.get(self, "flow_log_id")

    @property
    @pulumi.getter(name="flowLogName")
    def flow_log_name(self) -> pulumi.Output[builtins.str]:
        """
        流日志的名称。长度限制为1 ~ 128个字符。需要以字母、中文或数字开头，可包含点号（.）、下划线（_）和短横线（-）。不填默认为流日志实例的ID。
        """
        return pulumi.get(self, "flow_log_name")

    @property
    @pulumi.getter(name="lockReason")
    def lock_reason(self) -> pulumi.Output[builtins.str]:
        """
        流日志被锁定的原因。financial: 因欠费被锁定。unlock：欠费关停后充值恢复过程中。空值 : 没有被锁定。
        """
        return pulumi.get(self, "lock_reason")

    @property
    @pulumi.getter(name="logProjectId")
    def log_project_id(self) -> pulumi.Output[builtins.str]:
        """
        流日志项目的ID。
        """
        return pulumi.get(self, "log_project_id")

    @property
    @pulumi.getter(name="logProjectName")
    def log_project_name(self) -> pulumi.Output[builtins.str]:
        """
        流日志项目的名称。名称只能由小写字母、数字和连字符（-）组成。必须以小写字母或者数字开头和结尾。名称的长度范围为 3~63 个字符。
        """
        return pulumi.get(self, "log_project_name")

    @property
    @pulumi.getter(name="logTopicId")
    def log_topic_id(self) -> pulumi.Output[builtins.str]:
        """
        流日志主题的ID。
        """
        return pulumi.get(self, "log_topic_id")

    @property
    @pulumi.getter(name="logTopicName")
    def log_topic_name(self) -> pulumi.Output[builtins.str]:
        """
        流日志项目的名称。名称只能由小写字母、数字和连字符（-）组成。必须以小写字母或者数字开头和结尾。名称的长度范围为 3~63 个字符。
        """
        return pulumi.get(self, "log_topic_name")

    @property
    @pulumi.getter(name="projectName")
    def project_name(self) -> pulumi.Output[builtins.str]:
        """
        流流日志所属项目的名称。
        """
        return pulumi.get(self, "project_name")

    @property
    @pulumi.getter(name="resourceId")
    def resource_id(self) -> pulumi.Output[builtins.str]:
        """
        要捕获流量的资源ID。
        """
        return pulumi.get(self, "resource_id")

    @property
    @pulumi.getter(name="resourceType")
    def resource_type(self) -> pulumi.Output[builtins.str]:
        """
        要采集流量的资源类型，取值如下：vpc：私有网络。subnet：子网。eni：网卡。
        """
        return pulumi.get(self, "resource_type")

    @property
    @pulumi.getter
    def status(self) -> pulumi.Output[builtins.str]:
        """
        流日志的状态。取值如下：Active：启动状态。Pending：正在操作中。Inactive：未启动状态。Creating：正在创建中。Deleting：正在删除中。
        """
        return pulumi.get(self, "status")

    @property
    @pulumi.getter
    def tags(self) -> pulumi.Output[Sequence['outputs.FlowLogTag']]:
        return pulumi.get(self, "tags")

    @property
    @pulumi.getter(name="trafficType")
    def traffic_type(self) -> pulumi.Output[builtins.str]:
        """
        采集的流量类型。取值如下：All：全部流量。Allow：网络ACL和安全组允许的流量。Drop：网络ACL和安全组拒绝的流量。
        """
        return pulumi.get(self, "traffic_type")

    @property
    @pulumi.getter(name="updatedAt")
    def updated_at(self) -> pulumi.Output[builtins.str]:
        """
        更新流日志的时间。
        """
        return pulumi.get(self, "updated_at")

    @property
    @pulumi.getter(name="vpcId")
    def vpc_id(self) -> pulumi.Output[builtins.str]:
        """
        流日志的VPC的ID。
        """
        return pulumi.get(self, "vpc_id")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = ['KeyRingArgs', 'KeyRing']

@pulumi.input_type
class KeyRingArgs:
    def __init__(__self__, *,
                 keyring_name: pulumi.Input[builtins.str],
                 description: Optional[pulumi.Input[builtins.str]] = None,
                 keyring_type: Optional[pulumi.Input[builtins.str]] = None,
                 project_name: Optional[pulumi.Input[builtins.str]] = None):
        """
        The set of arguments for constructing a KeyRing resource.
        :param pulumi.Input[builtins.str] keyring_name: 密钥环名称，长度为 2   - 31 个字符。合法字符：[a-zA-Z0-9-_]。
        :param pulumi.Input[builtins.str] description: 密钥环描述，长度为 0   - 8192 个字符。
        :param pulumi.Input[builtins.str] keyring_type: 密钥环类型，取值：CustomKeyring。
        :param pulumi.Input[builtins.str] project_name: 项目名称，默认值：default。
        """
        pulumi.set(__self__, "keyring_name", keyring_name)
        if description is not None:
            pulumi.set(__self__, "description", description)
        if keyring_type is not None:
            pulumi.set(__self__, "keyring_type", keyring_type)
        if project_name is not None:
            pulumi.set(__self__, "project_name", project_name)

    @property
    @pulumi.getter(name="keyringName")
    def keyring_name(self) -> pulumi.Input[builtins.str]:
        """
        密钥环名称，长度为 2   - 31 个字符。合法字符：[a-zA-Z0-9-_]。
        """
        return pulumi.get(self, "keyring_name")

    @keyring_name.setter
    def keyring_name(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "keyring_name", value)

    @property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        密钥环描述，长度为 0   - 8192 个字符。
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "description", value)

    @property
    @pulumi.getter(name="keyringType")
    def keyring_type(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        密钥环类型，取值：CustomKeyring。
        """
        return pulumi.get(self, "keyring_type")

    @keyring_type.setter
    def keyring_type(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "keyring_type", value)

    @property
    @pulumi.getter(name="projectName")
    def project_name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        项目名称，默认值：default。
        """
        return pulumi.get(self, "project_name")

    @project_name.setter
    def project_name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "project_name", value)


@pulumi.input_type
class _KeyRingState:
    def __init__(__self__, *,
                 create_date: Optional[pulumi.Input[builtins.int]] = None,
                 description: Optional[pulumi.Input[builtins.str]] = None,
                 key_count: Optional[pulumi.Input[builtins.int]] = None,
                 key_ring_id: Optional[pulumi.Input[builtins.str]] = None,
                 keyring_name: Optional[pulumi.Input[builtins.str]] = None,
                 keyring_type: Optional[pulumi.Input[builtins.str]] = None,
                 project_name: Optional[pulumi.Input[builtins.str]] = None,
                 uid: Optional[pulumi.Input[builtins.str]] = None,
                 update_date: Optional[pulumi.Input[builtins.int]] = None):
        """
        Input properties used for looking up and filtering KeyRing resources.
        :param pulumi.Input[builtins.int] create_date: 密钥环创建日期。
        :param pulumi.Input[builtins.str] description: 密钥环描述，长度为 0   - 8192 个字符。
        :param pulumi.Input[builtins.int] key_count: 密钥环密钥次数。
        :param pulumi.Input[builtins.str] key_ring_id: 密钥环唯一标识符，UUID形式。
        :param pulumi.Input[builtins.str] keyring_name: 密钥环名称，长度为 2   - 31 个字符。合法字符：[a-zA-Z0-9-_]。
        :param pulumi.Input[builtins.str] keyring_type: 密钥环类型，取值：CustomKeyring。
        :param pulumi.Input[builtins.str] project_name: 项目名称，默认值：default。
        :param pulumi.Input[builtins.str] uid: 密钥环租户ID。
        :param pulumi.Input[builtins.int] update_date: 密钥环更新日期。
        """
        if create_date is not None:
            pulumi.set(__self__, "create_date", create_date)
        if description is not None:
            pulumi.set(__self__, "description", description)
        if key_count is not None:
            pulumi.set(__self__, "key_count", key_count)
        if key_ring_id is not None:
            pulumi.set(__self__, "key_ring_id", key_ring_id)
        if keyring_name is not None:
            pulumi.set(__self__, "keyring_name", keyring_name)
        if keyring_type is not None:
            pulumi.set(__self__, "keyring_type", keyring_type)
        if project_name is not None:
            pulumi.set(__self__, "project_name", project_name)
        if uid is not None:
            pulumi.set(__self__, "uid", uid)
        if update_date is not None:
            pulumi.set(__self__, "update_date", update_date)

    @property
    @pulumi.getter(name="createDate")
    def create_date(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        密钥环创建日期。
        """
        return pulumi.get(self, "create_date")

    @create_date.setter
    def create_date(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "create_date", value)

    @property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        密钥环描述，长度为 0   - 8192 个字符。
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "description", value)

    @property
    @pulumi.getter(name="keyCount")
    def key_count(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        密钥环密钥次数。
        """
        return pulumi.get(self, "key_count")

    @key_count.setter
    def key_count(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "key_count", value)

    @property
    @pulumi.getter(name="keyRingId")
    def key_ring_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        密钥环唯一标识符，UUID形式。
        """
        return pulumi.get(self, "key_ring_id")

    @key_ring_id.setter
    def key_ring_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "key_ring_id", value)

    @property
    @pulumi.getter(name="keyringName")
    def keyring_name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        密钥环名称，长度为 2   - 31 个字符。合法字符：[a-zA-Z0-9-_]。
        """
        return pulumi.get(self, "keyring_name")

    @keyring_name.setter
    def keyring_name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "keyring_name", value)

    @property
    @pulumi.getter(name="keyringType")
    def keyring_type(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        密钥环类型，取值：CustomKeyring。
        """
        return pulumi.get(self, "keyring_type")

    @keyring_type.setter
    def keyring_type(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "keyring_type", value)

    @property
    @pulumi.getter(name="projectName")
    def project_name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        项目名称，默认值：default。
        """
        return pulumi.get(self, "project_name")

    @project_name.setter
    def project_name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "project_name", value)

    @property
    @pulumi.getter
    def uid(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        密钥环租户ID。
        """
        return pulumi.get(self, "uid")

    @uid.setter
    def uid(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "uid", value)

    @property
    @pulumi.getter(name="updateDate")
    def update_date(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        密钥环更新日期。
        """
        return pulumi.get(self, "update_date")

    @update_date.setter
    def update_date(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "update_date", value)


@pulumi.type_token("bytepluscc:kms/keyRing:KeyRing")
class KeyRing(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 description: Optional[pulumi.Input[builtins.str]] = None,
                 keyring_name: Optional[pulumi.Input[builtins.str]] = None,
                 keyring_type: Optional[pulumi.Input[builtins.str]] = None,
                 project_name: Optional[pulumi.Input[builtins.str]] = None,
                 __props__=None):
        """
        用户管理密钥的集合，用户将相同类型或用途的密钥放在同一密钥环中以便于管理。

        ## Example Usage

        ```python
        import pulumi
        import pulumi_bytepluscc as bytepluscc

        kmskeyring_demo = bytepluscc.kms.KeyRing("kmskeyringDemo",
            description="this is a test update",
            keyring_name="ccapi-test",
            keyring_type="CustomKeyring",
            project_name="default")
        ```

        ## Import

        ```sh
        $ pulumi import bytepluscc:kms/keyRing:KeyRing example "key_ring_id"
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.str] description: 密钥环描述，长度为 0   - 8192 个字符。
        :param pulumi.Input[builtins.str] keyring_name: 密钥环名称，长度为 2   - 31 个字符。合法字符：[a-zA-Z0-9-_]。
        :param pulumi.Input[builtins.str] keyring_type: 密钥环类型，取值：CustomKeyring。
        :param pulumi.Input[builtins.str] project_name: 项目名称，默认值：default。
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: KeyRingArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        用户管理密钥的集合，用户将相同类型或用途的密钥放在同一密钥环中以便于管理。

        ## Example Usage

        ```python
        import pulumi
        import pulumi_bytepluscc as bytepluscc

        kmskeyring_demo = bytepluscc.kms.KeyRing("kmskeyringDemo",
            description="this is a test update",
            keyring_name="ccapi-test",
            keyring_type="CustomKeyring",
            project_name="default")
        ```

        ## Import

        ```sh
        $ pulumi import bytepluscc:kms/keyRing:KeyRing example "key_ring_id"
        ```

        :param str resource_name: The name of the resource.
        :param KeyRingArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(KeyRingArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 description: Optional[pulumi.Input[builtins.str]] = None,
                 keyring_name: Optional[pulumi.Input[builtins.str]] = None,
                 keyring_type: Optional[pulumi.Input[builtins.str]] = None,
                 project_name: Optional[pulumi.Input[builtins.str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = KeyRingArgs.__new__(KeyRingArgs)

            __props__.__dict__["description"] = description
            if keyring_name is None and not opts.urn:
                raise TypeError("Missing required property 'keyring_name'")
            __props__.__dict__["keyring_name"] = keyring_name
            __props__.__dict__["keyring_type"] = keyring_type
            __props__.__dict__["project_name"] = project_name
            __props__.__dict__["create_date"] = None
            __props__.__dict__["key_count"] = None
            __props__.__dict__["key_ring_id"] = None
            __props__.__dict__["uid"] = None
            __props__.__dict__["update_date"] = None
        super(KeyRing, __self__).__init__(
            'bytepluscc:kms/keyRing:KeyRing',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            create_date: Optional[pulumi.Input[builtins.int]] = None,
            description: Optional[pulumi.Input[builtins.str]] = None,
            key_count: Optional[pulumi.Input[builtins.int]] = None,
            key_ring_id: Optional[pulumi.Input[builtins.str]] = None,
            keyring_name: Optional[pulumi.Input[builtins.str]] = None,
            keyring_type: Optional[pulumi.Input[builtins.str]] = None,
            project_name: Optional[pulumi.Input[builtins.str]] = None,
            uid: Optional[pulumi.Input[builtins.str]] = None,
            update_date: Optional[pulumi.Input[builtins.int]] = None) -> 'KeyRing':
        """
        Get an existing KeyRing resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.int] create_date: 密钥环创建日期。
        :param pulumi.Input[builtins.str] description: 密钥环描述，长度为 0   - 8192 个字符。
        :param pulumi.Input[builtins.int] key_count: 密钥环密钥次数。
        :param pulumi.Input[builtins.str] key_ring_id: 密钥环唯一标识符，UUID形式。
        :param pulumi.Input[builtins.str] keyring_name: 密钥环名称，长度为 2   - 31 个字符。合法字符：[a-zA-Z0-9-_]。
        :param pulumi.Input[builtins.str] keyring_type: 密钥环类型，取值：CustomKeyring。
        :param pulumi.Input[builtins.str] project_name: 项目名称，默认值：default。
        :param pulumi.Input[builtins.str] uid: 密钥环租户ID。
        :param pulumi.Input[builtins.int] update_date: 密钥环更新日期。
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _KeyRingState.__new__(_KeyRingState)

        __props__.__dict__["create_date"] = create_date
        __props__.__dict__["description"] = description
        __props__.__dict__["key_count"] = key_count
        __props__.__dict__["key_ring_id"] = key_ring_id
        __props__.__dict__["keyring_name"] = keyring_name
        __props__.__dict__["keyring_type"] = keyring_type
        __props__.__dict__["project_name"] = project_name
        __props__.__dict__["uid"] = uid
        __props__.__dict__["update_date"] = update_date
        return KeyRing(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="createDate")
    def create_date(self) -> pulumi.Output[builtins.int]:
        """
        密钥环创建日期。
        """
        return pulumi.get(self, "create_date")

    @property
    @pulumi.getter
    def description(self) -> pulumi.Output[builtins.str]:
        """
        密钥环描述，长度为 0   - 8192 个字符。
        """
        return pulumi.get(self, "description")

    @property
    @pulumi.getter(name="keyCount")
    def key_count(self) -> pulumi.Output[builtins.int]:
        """
        密钥环密钥次数。
        """
        return pulumi.get(self, "key_count")

    @property
    @pulumi.getter(name="keyRingId")
    def key_ring_id(self) -> pulumi.Output[builtins.str]:
        """
        密钥环唯一标识符，UUID形式。
        """
        return pulumi.get(self, "key_ring_id")

    @property
    @pulumi.getter(name="keyringName")
    def keyring_name(self) -> pulumi.Output[builtins.str]:
        """
        密钥环名称，长度为 2   - 31 个字符。合法字符：[a-zA-Z0-9-_]。
        """
        return pulumi.get(self, "keyring_name")

    @property
    @pulumi.getter(name="keyringType")
    def keyring_type(self) -> pulumi.Output[builtins.str]:
        """
        密钥环类型，取值：CustomKeyring。
        """
        return pulumi.get(self, "keyring_type")

    @property
    @pulumi.getter(name="projectName")
    def project_name(self) -> pulumi.Output[builtins.str]:
        """
        项目名称，默认值：default。
        """
        return pulumi.get(self, "project_name")

    @property
    @pulumi.getter
    def uid(self) -> pulumi.Output[builtins.str]:
        """
        密钥环租户ID。
        """
        return pulumi.get(self, "uid")

    @property
    @pulumi.getter(name="updateDate")
    def update_date(self) -> pulumi.Output[builtins.int]:
        """
        密钥环更新日期。
        """
        return pulumi.get(self, "update_date")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs

__all__ = [
    'GetInstanceResult',
    'AwaitableGetInstanceResult',
    'get_instance',
    'get_instance_output',
]

@pulumi.output_type
class GetInstanceResult:
    """
    A collection of values returned by getInstance.
    """
    def __init__(__self__, account_id=None, apply_private_dns_to_public=None, arch_type=None, charge_detail=None, compute_spec=None, created_time=None, eip_id=None, endpoints=None, id=None, instance_description=None, instance_id=None, instance_name=None, instance_status=None, is_encrypted=None, project_name=None, storage_space=None, subnet_id=None, tags=None, used_storage_space=None, user_name=None, user_password=None, version=None, vpc_id=None, zone_description=None, zone_id=None):
        if account_id and not isinstance(account_id, str):
            raise TypeError("Expected argument 'account_id' to be a str")
        pulumi.set(__self__, "account_id", account_id)
        if apply_private_dns_to_public and not isinstance(apply_private_dns_to_public, bool):
            raise TypeError("Expected argument 'apply_private_dns_to_public' to be a bool")
        pulumi.set(__self__, "apply_private_dns_to_public", apply_private_dns_to_public)
        if arch_type and not isinstance(arch_type, str):
            raise TypeError("Expected argument 'arch_type' to be a str")
        pulumi.set(__self__, "arch_type", arch_type)
        if charge_detail and not isinstance(charge_detail, dict):
            raise TypeError("Expected argument 'charge_detail' to be a dict")
        pulumi.set(__self__, "charge_detail", charge_detail)
        if compute_spec and not isinstance(compute_spec, str):
            raise TypeError("Expected argument 'compute_spec' to be a str")
        pulumi.set(__self__, "compute_spec", compute_spec)
        if created_time and not isinstance(created_time, str):
            raise TypeError("Expected argument 'created_time' to be a str")
        pulumi.set(__self__, "created_time", created_time)
        if eip_id and not isinstance(eip_id, str):
            raise TypeError("Expected argument 'eip_id' to be a str")
        pulumi.set(__self__, "eip_id", eip_id)
        if endpoints and not isinstance(endpoints, list):
            raise TypeError("Expected argument 'endpoints' to be a list")
        pulumi.set(__self__, "endpoints", endpoints)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if instance_description and not isinstance(instance_description, str):
            raise TypeError("Expected argument 'instance_description' to be a str")
        pulumi.set(__self__, "instance_description", instance_description)
        if instance_id and not isinstance(instance_id, str):
            raise TypeError("Expected argument 'instance_id' to be a str")
        pulumi.set(__self__, "instance_id", instance_id)
        if instance_name and not isinstance(instance_name, str):
            raise TypeError("Expected argument 'instance_name' to be a str")
        pulumi.set(__self__, "instance_name", instance_name)
        if instance_status and not isinstance(instance_status, str):
            raise TypeError("Expected argument 'instance_status' to be a str")
        pulumi.set(__self__, "instance_status", instance_status)
        if is_encrypted and not isinstance(is_encrypted, bool):
            raise TypeError("Expected argument 'is_encrypted' to be a bool")
        pulumi.set(__self__, "is_encrypted", is_encrypted)
        if project_name and not isinstance(project_name, str):
            raise TypeError("Expected argument 'project_name' to be a str")
        pulumi.set(__self__, "project_name", project_name)
        if storage_space and not isinstance(storage_space, int):
            raise TypeError("Expected argument 'storage_space' to be a int")
        pulumi.set(__self__, "storage_space", storage_space)
        if subnet_id and not isinstance(subnet_id, str):
            raise TypeError("Expected argument 'subnet_id' to be a str")
        pulumi.set(__self__, "subnet_id", subnet_id)
        if tags and not isinstance(tags, list):
            raise TypeError("Expected argument 'tags' to be a list")
        pulumi.set(__self__, "tags", tags)
        if used_storage_space and not isinstance(used_storage_space, int):
            raise TypeError("Expected argument 'used_storage_space' to be a int")
        pulumi.set(__self__, "used_storage_space", used_storage_space)
        if user_name and not isinstance(user_name, str):
            raise TypeError("Expected argument 'user_name' to be a str")
        pulumi.set(__self__, "user_name", user_name)
        if user_password and not isinstance(user_password, str):
            raise TypeError("Expected argument 'user_password' to be a str")
        pulumi.set(__self__, "user_password", user_password)
        if version and not isinstance(version, str):
            raise TypeError("Expected argument 'version' to be a str")
        pulumi.set(__self__, "version", version)
        if vpc_id and not isinstance(vpc_id, str):
            raise TypeError("Expected argument 'vpc_id' to be a str")
        pulumi.set(__self__, "vpc_id", vpc_id)
        if zone_description and not isinstance(zone_description, str):
            raise TypeError("Expected argument 'zone_description' to be a str")
        pulumi.set(__self__, "zone_description", zone_description)
        if zone_id and not isinstance(zone_id, str):
            raise TypeError("Expected argument 'zone_id' to be a str")
        pulumi.set(__self__, "zone_id", zone_id)

    @property
    @pulumi.getter(name="accountId")
    def account_id(self) -> builtins.str:
        """
        创建实例的主账号ID。
        """
        return pulumi.get(self, "account_id")

    @property
    @pulumi.getter(name="applyPrivateDnsToPublic")
    def apply_private_dns_to_public(self) -> builtins.bool:
        """
        是否已开启公网解析功能。true：已开启, false：已关闭
        """
        return pulumi.get(self, "apply_private_dns_to_public")

    @property
    @pulumi.getter(name="archType")
    def arch_type(self) -> builtins.str:
        """
        实例的类型，即集群版或单机版。
        """
        return pulumi.get(self, "arch_type")

    @property
    @pulumi.getter(name="chargeDetail")
    def charge_detail(self) -> 'outputs.GetInstanceChargeDetailResult':
        """
        实例的计费方式等计费信息。
        """
        return pulumi.get(self, "charge_detail")

    @property
    @pulumi.getter(name="computeSpec")
    def compute_spec(self) -> builtins.str:
        """
        RabbitMQ实例的计算规格。
        """
        return pulumi.get(self, "compute_spec")

    @property
    @pulumi.getter(name="createdTime")
    def created_time(self) -> builtins.str:
        """
        实例的创建时间。
        """
        return pulumi.get(self, "created_time")

    @property
    @pulumi.getter(name="eipId")
    def eip_id(self) -> builtins.str:
        """
        EIP的ID。
        """
        return pulumi.get(self, "eip_id")

    @property
    @pulumi.getter
    def endpoints(self) -> Sequence['outputs.GetInstanceEndpointResult']:
        """
        实例的连接信息。
        """
        return pulumi.get(self, "endpoints")

    @property
    @pulumi.getter
    def id(self) -> builtins.str:
        """
        Uniquely identifies the resource.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter(name="instanceDescription")
    def instance_description(self) -> builtins.str:
        """
        实例的简单描述。
        """
        return pulumi.get(self, "instance_description")

    @property
    @pulumi.getter(name="instanceId")
    def instance_id(self) -> builtins.str:
        """
        RabbitMQ 实例 ID。
        """
        return pulumi.get(self, "instance_id")

    @property
    @pulumi.getter(name="instanceName")
    def instance_name(self) -> builtins.str:
        """
        RabbitMQ 实例名称。
        """
        return pulumi.get(self, "instance_name")

    @property
    @pulumi.getter(name="instanceStatus")
    def instance_status(self) -> builtins.str:
        """
        实例状态。
        """
        return pulumi.get(self, "instance_status")

    @property
    @pulumi.getter(name="isEncrypted")
    def is_encrypted(self) -> builtins.bool:
        """
        是否开启了云盘加密。
        """
        return pulumi.get(self, "is_encrypted")

    @property
    @pulumi.getter(name="projectName")
    def project_name(self) -> builtins.str:
        """
        实例所属的IAM项目。
        """
        return pulumi.get(self, "project_name")

    @property
    @pulumi.getter(name="storageSpace")
    def storage_space(self) -> builtins.int:
        """
        实例总存储空间。单位为 GiB。
        """
        return pulumi.get(self, "storage_space")

    @property
    @pulumi.getter(name="subnetId")
    def subnet_id(self) -> builtins.str:
        """
        VPC的子网ID。
        """
        return pulumi.get(self, "subnet_id")

    @property
    @pulumi.getter
    def tags(self) -> Sequence['outputs.GetInstanceTagResult']:
        """
        实例绑定的标签。
        """
        return pulumi.get(self, "tags")

    @property
    @pulumi.getter(name="usedStorageSpace")
    def used_storage_space(self) -> builtins.int:
        """
        实例已用存储空间。单位为 GiB。
        """
        return pulumi.get(self, "used_storage_space")

    @property
    @pulumi.getter(name="userName")
    def user_name(self) -> builtins.str:
        """
        RabbitMQ WebUI管理员账号名。
        """
        return pulumi.get(self, "user_name")

    @property
    @pulumi.getter(name="userPassword")
    def user_password(self) -> builtins.str:
        """
        RabbitMQ WebUI管理员密码。
        """
        return pulumi.get(self, "user_password")

    @property
    @pulumi.getter
    def version(self) -> builtins.str:
        """
        支持的 RabbitMQ 版本。当前支持的版本包括：3.8.18：RabbitMQ 3.8.18 版本。
        """
        return pulumi.get(self, "version")

    @property
    @pulumi.getter(name="vpcId")
    def vpc_id(self) -> builtins.str:
        """
        私有网络（VPC）ID。
        """
        return pulumi.get(self, "vpc_id")

    @property
    @pulumi.getter(name="zoneDescription")
    def zone_description(self) -> builtins.str:
        """
        可用区的描述信息。
        """
        return pulumi.get(self, "zone_description")

    @property
    @pulumi.getter(name="zoneId")
    def zone_id(self) -> builtins.str:
        """
        实例所在的可用区 ID。对于跨 AZ 的高可用实例，此处会返回多个可用区 ID。
        """
        return pulumi.get(self, "zone_id")


class AwaitableGetInstanceResult(GetInstanceResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetInstanceResult(
            account_id=self.account_id,
            apply_private_dns_to_public=self.apply_private_dns_to_public,
            arch_type=self.arch_type,
            charge_detail=self.charge_detail,
            compute_spec=self.compute_spec,
            created_time=self.created_time,
            eip_id=self.eip_id,
            endpoints=self.endpoints,
            id=self.id,
            instance_description=self.instance_description,
            instance_id=self.instance_id,
            instance_name=self.instance_name,
            instance_status=self.instance_status,
            is_encrypted=self.is_encrypted,
            project_name=self.project_name,
            storage_space=self.storage_space,
            subnet_id=self.subnet_id,
            tags=self.tags,
            used_storage_space=self.used_storage_space,
            user_name=self.user_name,
            user_password=self.user_password,
            version=self.version,
            vpc_id=self.vpc_id,
            zone_description=self.zone_description,
            zone_id=self.zone_id)


def get_instance(id: Optional[builtins.str] = None,
                 opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetInstanceResult:
    """
    Data Source schema for Byteplus::RabbitMQ::Instance


    :param builtins.str id: Uniquely identifies the resource.
    """
    __args__ = dict()
    __args__['id'] = id
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('bytepluscc:rabbitmq/getInstance:getInstance', __args__, opts=opts, typ=GetInstanceResult).value

    return AwaitableGetInstanceResult(
        account_id=pulumi.get(__ret__, 'account_id'),
        apply_private_dns_to_public=pulumi.get(__ret__, 'apply_private_dns_to_public'),
        arch_type=pulumi.get(__ret__, 'arch_type'),
        charge_detail=pulumi.get(__ret__, 'charge_detail'),
        compute_spec=pulumi.get(__ret__, 'compute_spec'),
        created_time=pulumi.get(__ret__, 'created_time'),
        eip_id=pulumi.get(__ret__, 'eip_id'),
        endpoints=pulumi.get(__ret__, 'endpoints'),
        id=pulumi.get(__ret__, 'id'),
        instance_description=pulumi.get(__ret__, 'instance_description'),
        instance_id=pulumi.get(__ret__, 'instance_id'),
        instance_name=pulumi.get(__ret__, 'instance_name'),
        instance_status=pulumi.get(__ret__, 'instance_status'),
        is_encrypted=pulumi.get(__ret__, 'is_encrypted'),
        project_name=pulumi.get(__ret__, 'project_name'),
        storage_space=pulumi.get(__ret__, 'storage_space'),
        subnet_id=pulumi.get(__ret__, 'subnet_id'),
        tags=pulumi.get(__ret__, 'tags'),
        used_storage_space=pulumi.get(__ret__, 'used_storage_space'),
        user_name=pulumi.get(__ret__, 'user_name'),
        user_password=pulumi.get(__ret__, 'user_password'),
        version=pulumi.get(__ret__, 'version'),
        vpc_id=pulumi.get(__ret__, 'vpc_id'),
        zone_description=pulumi.get(__ret__, 'zone_description'),
        zone_id=pulumi.get(__ret__, 'zone_id'))
def get_instance_output(id: Optional[pulumi.Input[builtins.str]] = None,
                        opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetInstanceResult]:
    """
    Data Source schema for Byteplus::RabbitMQ::Instance


    :param builtins.str id: Uniquely identifies the resource.
    """
    __args__ = dict()
    __args__['id'] = id
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('bytepluscc:rabbitmq/getInstance:getInstance', __args__, opts=opts, typ=GetInstanceResult)
    return __ret__.apply(lambda __response__: GetInstanceResult(
        account_id=pulumi.get(__response__, 'account_id'),
        apply_private_dns_to_public=pulumi.get(__response__, 'apply_private_dns_to_public'),
        arch_type=pulumi.get(__response__, 'arch_type'),
        charge_detail=pulumi.get(__response__, 'charge_detail'),
        compute_spec=pulumi.get(__response__, 'compute_spec'),
        created_time=pulumi.get(__response__, 'created_time'),
        eip_id=pulumi.get(__response__, 'eip_id'),
        endpoints=pulumi.get(__response__, 'endpoints'),
        id=pulumi.get(__response__, 'id'),
        instance_description=pulumi.get(__response__, 'instance_description'),
        instance_id=pulumi.get(__response__, 'instance_id'),
        instance_name=pulumi.get(__response__, 'instance_name'),
        instance_status=pulumi.get(__response__, 'instance_status'),
        is_encrypted=pulumi.get(__response__, 'is_encrypted'),
        project_name=pulumi.get(__response__, 'project_name'),
        storage_space=pulumi.get(__response__, 'storage_space'),
        subnet_id=pulumi.get(__response__, 'subnet_id'),
        tags=pulumi.get(__response__, 'tags'),
        used_storage_space=pulumi.get(__response__, 'used_storage_space'),
        user_name=pulumi.get(__response__, 'user_name'),
        user_password=pulumi.get(__response__, 'user_password'),
        version=pulumi.get(__response__, 'version'),
        vpc_id=pulumi.get(__response__, 'vpc_id'),
        zone_description=pulumi.get(__response__, 'zone_description'),
        zone_id=pulumi.get(__response__, 'zone_id')))
